FunctionCallOutput class sealed

The output of a function call.

Can be either a simple string or a list of content items.

Implementers

Constructors

FunctionCallOutput.fromJson(Object json)
Creates a FunctionCallOutput from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited