OpenResponsesClient constructor

OpenResponsesClient({
  1. OpenResponsesConfig? config,
  2. Client? httpClient,
})

Creates an OpenResponsesClient.

If httpClient is not provided, a new client is created and will be closed when close is called.

Implementation

OpenResponsesClient({OpenResponsesConfig? config, http.Client? httpClient})
  : config = config ?? const OpenResponsesConfig(),
    _httpClient = httpClient ?? http.Client(),
    _ownsHttpClient = httpClient == null {
  _initialize();
}