OutputTextContent class

Text output content.

Inheritance
Annotations
  • @immutable

Constructors

OutputTextContent({required String text, List<Annotation>? annotations, List<LogProb>? logprobs})
Creates an OutputTextContent.
const
OutputTextContent.fromJson(Map<String, dynamic> json)
Creates an OutputTextContent from JSON.
factory

Properties

annotations List<Annotation>?
Optional annotations (citations, etc.).
final
hashCode int
The hash code for this object.
no setteroverride
logprobs List<LogProb>?
Optional log probabilities.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content.
final

Methods

copyWith({String? text, Object? annotations = unsetCopyWithValue, Object? logprobs = unsetCopyWithValue}) OutputTextContent
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override