ReasoningConfig class
Configuration for reasoning models.
- Annotations
-
- @immutable
Constructors
- ReasoningConfig({ReasoningEffort? effort, ReasoningSummary? summary})
-
Creates a ReasoningConfig.
const
-
ReasoningConfig.fromJson(Map<
String, dynamic> json) -
Creates a ReasoningConfig from JSON.
factory
Properties
- effort → ReasoningEffort?
-
The reasoning effort level.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → ReasoningSummary?
-
How to summarize the reasoning.
final
Methods
-
copyWith(
{Object? effort = unsetCopyWithValue, Object? summary = unsetCopyWithValue}) → ReasoningConfig - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override