ReasoningItem class

A reasoning item from reasoning models.

Inheritance
Annotations
  • @immutable

Constructors

ReasoningItem({required String id, List<Map<String, dynamic>>? content, required List<ReasoningSummaryContent> summary, String? encryptedContent})
Creates a ReasoningItem.
const
ReasoningItem.fromJson(Map<String, dynamic> json)
Creates a ReasoningItem from JSON.
factory

Properties

content List<Map<String, dynamic>>?
The reasoning content that was generated.
final
encryptedContent String?
Encrypted reasoning content (if requested via include).
final
hashCode int
The hash code for this object.
no setteroverride
id String
Unique identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary List<ReasoningSummaryContent>
The reasoning summary content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override