StreamingEvent class sealed

Server-sent event for response streaming.

Implementers
Available extensions

Constructors

StreamingEvent.fromJson(Map<String, dynamic> json)
Creates a StreamingEvent from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isFinal bool

Available on StreamingEvent, provided by the StreamingEventExtensions extension

Whether this is the final event (response completed/failed/incomplete).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textDelta String?

Available on StreamingEvent, provided by the StreamingEventExtensions extension

Extract text delta if this is a text delta event.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited