UserMessagePartsContent class

List of input content parts for a user message.

Inheritance
Annotations
  • @immutable

Constructors

UserMessagePartsContent(List<InputContent> parts)
Creates a UserMessagePartsContent.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
parts List<InputContent>
The content parts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Extracts the text from this content.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Converts to JSON.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override