McpTool class
A Model Context Protocol (MCP) tool.
Allows connecting to remote MCP servers for extended capabilities.
Note: This is an extension tool type not present in the official OpenResponses spec. It is included for compatibility with providers that support the Model Context Protocol.
Constructors
Properties
-
allowedTools
→ List<
String> ? -
List of allowed tools from this server.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- requireApproval → String?
-
Approval requirement for tool execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverLabel → String
-
Label for the MCP server.
final
- serverUrl → String
-
URL of the MCP server.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override