OpenResponsesException class sealed
Base sealed class for all OpenResponses exceptions.
Subtypes:
- ApiException — HTTP/API errors (includes AuthenticationException, RateLimitException)
- ValidationException — Client-side validation errors
- TimeoutException — Request timeouts
- AbortedException — Request cancellation
- Implemented types
- Implementers
Properties
- cause → Exception?
-
Original exception that caused this exception (for exception chaining).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Optional stack trace.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited