ResponseQueuedEvent class
Event indicating a response was queued.
- Inheritance
-
- Object
- StreamingEvent
- ResponseQueuedEvent
- Available extensions
- Annotations
-
- @immutable
Constructors
- ResponseQueuedEvent({required int sequenceNumber, required ResponseResource response})
-
Creates a ResponseQueuedEvent.
const
-
ResponseQueuedEvent.fromJson(Map<
String, dynamic> json) -
Creates a ResponseQueuedEvent from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFinal → bool
-
Available on StreamingEvent, provided by the StreamingEventExtensions extension
Whether this is the final event (response completed/failed/incomplete).no setter - response → ResponseResource
-
The queued response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceNumber → int
-
The sequence number of the event.
final
- textDelta → String?
-
Available on StreamingEvent, provided by the StreamingEventExtensions extension
Extract text delta if this is a text delta event.no setter - type → String
-
The event type.
no setter
Methods
-
copyWith(
{int? sequenceNumber, ResponseResource? response}) → ResponseQueuedEvent - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override